@@ -224,7 +224,7 @@ parse2dict_boolean_callback (void *context, int boolean)
 {
     yajltcl_clientData *yajlData = context;
 
-    Tcl_DStringAppendElement (&yajlData->p2dString, boolean ? "1" : "0");
+    Tcl_DStringAppendElement (&yajlData->p2dString, boolean ? "true" : "false");
     return 1;
 }
 
@@ -967,8 +967,8 @@ yajltcl_yajlObjectObjCmd(ClientData cData, Tcl_Interp *interp, int objc, Tcl_Obj
 
 	  // number? generate a number string and value
           case OPT_NUMBER: {
-              char *number;
-              int   len;
+              char 	    *number;
+              yajltcl_size   len;
 
               if (arg + 1 >= objc) {
                   Tcl_WrongNumArgs (interp, 1, objv, "number value");
@@ -980,7 +980,7 @@ yajltcl_yajlObjectObjCmd(ClientData cData, Tcl_Interp *interp, int objc, Tcl_Obj
                 Tcl_AppendResult(interp, "Invalid value \"", number ,"\" for number input.", NULL);
                 return TCL_ERROR;
               }
-              gstatus = yajl_gen_number (hand, number, len);
+              gstatus = yajl_gen_number (hand, number, (int)len);
               break;
           }
 
@@ -988,7 +988,7 @@ yajltcl_yajlObjectObjCmd(ClientData cData, Tcl_Interp *interp, int objc, Tcl_Obj
           case OPT_MAP_KEY:
           case OPT_STRING: {
               char *string;
-              int   len;
+              yajltcl_size len;
 
               if (arg + 1 >= objc) {
                   Tcl_WrongNumArgs (interp, 1, objv, "string value");
@@ -996,7 +996,7 @@ yajltcl_yajlObjectObjCmd(ClientData cData, Tcl_Interp *interp, int objc, Tcl_Obj
               }
 
               string = Tcl_GetStringFromObj (objv[++arg], &len);
-              gstatus = yajl_gen_string (hand, (unsigned char *)string, len);
+              gstatus = yajl_gen_string (hand, (unsigned char *)string, (int)len);
               break;
           }
 
@@ -1007,7 +1007,7 @@ yajltcl_yajlObjectObjCmd(ClientData cData, Tcl_Interp *interp, int objc, Tcl_Obj
           case OPT_PARSE2HUDDLE:
           case OPT_PARSE: {
               char *string;
-              int   len;
+              yajltcl_size len;
 	      yajl_handle parseHandle = NULL;
 
               if (arg + 1 >= objc) {
@@ -1024,7 +1024,7 @@ yajltcl_yajlObjectObjCmd(ClientData cData, Tcl_Interp *interp, int objc, Tcl_Obj
 	      }
 
               string = Tcl_GetStringFromObj (objv[++arg], &len);
-              pstatus = yajl_parse (parseHandle, (unsigned char *)string, len);
+              pstatus = yajl_parse (parseHandle, (unsigned char *)string,(int)len);
 
               if (pstatus != yajl_status_ok) {
                   unsigned char *str = yajl_get_error (parseHandle, 1, (unsigned char *)string, len);
@@ -1282,12 +1282,12 @@ yajltcl_yajlObjCmd(clientData, interp, objc, objv)
     if (strcmp (commandName, "#auto") == 0) {
         static unsigned long nextAutoCounter = 0;
         char *objName;
-        int    baseNameLength;
+        yajltcl_size    baseNameLength;
 
         objName = Tcl_GetStringFromObj (objv[0], &baseNameLength);
         baseNameLength += snprintf (NULL, 0, "%lu", nextAutoCounter) + 1;
-        commandName = ckalloc (baseNameLength);
-        snprintf (commandName, baseNameLength, "%s%lu", objName, nextAutoCounter++);
+        commandName = ckalloc ((size_t)baseNameLength);
+        snprintf (commandName, (size_t)baseNameLength, "%s%lu", objName, nextAutoCounter++);
         autoGeneratedName = 1;
     }
 
